BufferKind

Enum BufferKind 

pub enum BufferKind {
    Vertex,
    Index,
    Uniform,
    PixelRead,
    PixelWrite,
}
GPU buffer kind, as used in GpuBufferDescriptor.

Variants



Vertex

Vertex buffer. It is used to supply vertex data (such as positions, normals, texture coordinates, etc.) to GPU.



Index

Index buffer. It is used to describe how vertices forms specific types of primitives. For example a quad could be described by a set of 4 vertices, but 2 triangles which in their turn consists of 6 indices (0,1,2,0,2,3 vertex indices).



Uniform

Uniform buffer. It is used to supply context-specific data that is needed for rendering. Usually it contains data that changes from frame-to-frame (world transform, color, etc.).



PixelRead

Pixel read buffer. It is a special buffer that is used to asynchronously read-back data from GPU.



PixelWrite

Pixel write buffer. It is a special buffer that is used to write some data to GPU asynchronously.