pub enum BufferUsage {
StreamDraw,
StreamRead,
StreamCopy,
StaticDraw,
StaticRead,
StaticCopy,
DynamicDraw,
DynamicRead,
DynamicCopy,
}Expand description
A hint for video driver that allows it to optimize buffer’s content for more efficient use.
Variants
StreamDraw
The buffer contents will be modified once and used at most a few times. The buffer contents are modified by the application, and used as the source for drawing and image specification commands.
StreamRead
The buffer contents will be modified once and used at most a few times. The buffer contents are modified by reading data from the GPU, and used to return that data when queried by the application.
StreamCopy
The buffer contents will be modified once and used at most a few times. The buffer contents are modified by the application, and used as the source for drawing and image specification commands.
StaticDraw
The buffer contents will be modified once and used many times. The buffer contents are modified by the application, and used as the source for drawing and image specification commands.
StaticRead
The buffer contents will be modified once and used many times. The buffer contents are modified by reading data from the GPU, and used to return that data when queried by the application.
StaticCopy
The buffer contents will be modified once and used many times. The buffer contents are modified by reading data from the GPU, and used as the source for drawing and image specification commands.
DynamicDraw
The buffer contents will be modified repeatedly and used many times. The buffer contents are modified by the application, and used as the source for drawing and image specification commands.
DynamicRead
The buffer contents will be modified repeatedly and used many times. The buffer contents are modified by reading data from the GPU, and used to return that data when queried by the application.
DynamicCopy
The buffer contents will be modified repeatedly and used many times. The buffer contents are modified by reading data from the GPU, and used as the source for drawing and image specification commands.