pub enum FrameworkError {
Show 13 variants
ShaderCompilationFailed {
shader_name: String,
error_message: String,
},
ShaderLinkingFailed {
shader_name: String,
error_message: String,
},
FaultyShaderSource,
UnableToFindShaderUniform(String),
UnableToFindShaderUniformBlock(String),
InvalidTextureData {
expected_data_size: usize,
actual_data_size: usize,
},
EmptyTextureData,
InvalidElementRange {
start: usize,
end: usize,
total: usize,
},
InvalidAttributeDescriptor,
InvalidFrameBuffer,
FailedToConstructFBO,
Custom(String),
GraphicsServerUnavailable,
}Expand description
Set of possible renderer errors.
Variants
ShaderCompilationFailed
Compilation of a shader has failed.
ShaderLinkingFailed
Means that shader link stage failed, exact reason is inside error_message
FaultyShaderSource
Shader source contains invalid characters.
UnableToFindShaderUniform(String)
There is no such shader uniform (could be optimized out).
UnableToFindShaderUniformBlock(String)
There is no such shader uniform block.
InvalidTextureData
Texture has invalid data - insufficient size.
Fields
EmptyTextureData
None variant was passed as texture data, but engine does not support it.
InvalidElementRange
Means that you tried to draw element range from GeometryBuffer that does not have enough elements.
InvalidAttributeDescriptor
Means that attribute descriptor tries to define an attribute that does not exists in vertex, or it does not match size. For example you have vertex: pos: float2, normal: float3 But you described second attribute as Float4, then you’ll get this error.
InvalidFrameBuffer
Framebuffer is invalid.
FailedToConstructFBO
OpenGL failed to construct framebuffer.
Custom(String)
Custom error. Usually used for internal errors.
Graphics server disconnected.