pub enum AttachmentKind {
Color,
DepthStencil,
Depth,
}Expand description
Frame buffer attachment kind.
Variants
Color
Color attachment, it should have a format that supports rendering (for example it cannot be a compressed texture format).
DepthStencil
Combined depth + stencil (usually it is 24 bits for depth and 8 for stencil) attachment.
Depth
Depth-only attachment. Usually it is 16 or 32 bits texture.