ResourceBinding

Enum ResourceBinding 

pub enum ResourceBinding {
    Texture {
        texture: GpuTexture,
        sampler: GpuSampler,
        binding: usize,
    },
    Buffer {
        buffer: GpuBuffer,
        binding: usize,
        data_usage: BufferDataUsage,
    },
}
A resource binding defines where to bind specific GPU resources.

Variants



Texture

Texture binding.

Fields

texture: GpuTexture

A shared reference to a texture.

sampler: GpuSampler

A sampler that will be used to fetch the data from the texture.

binding: usize

Binding mode for the texture. glUniform1i is used to assign this binding point to a texture uniform.



Buffer

Generic data buffer binding.

Fields

buffer: GpuBuffer

A shared reference to a buffer.

binding: usize

Binding mode for the buffer.

data_usage: BufferDataUsage

Data portion to use.

Implementations

Source

impl ResourceBinding

pub fn texture( texture: &GpuTexture, sampler: &GpuSampler, binding: usize, ) -> Self

Creates a new explicit texture binding.

pub fn buffer( buffer: &GpuBuffer, binding: usize, data_usage: BufferDataUsage, ) -> Self

Creates a new explicit buffer binding.