Attachment

Struct Attachment 

pub struct Attachment {
    pub kind: AttachmentKind,
    pub texture: GpuTexture,
    /* private fields */
}
A frame buffer attachment that tells the frame buffer object where to store the results of rendering.

Fields

kind: AttachmentKind

Current kind of attachment. Tells the renderer how the texture should be used when rendering to the frame buffer. For example, is it color or depth?

texture: GpuTexture

A texture the renderer writes to. It may be writing the actual image, or it may just be writing the depth, or stencil, depending on kind.

Implementations

Source

impl Attachment

pub fn level(&self) -> usize

Mip level of the texture where the rendering should happen. In most cases, it can be zero.

pub fn cube_map_face(&self) -> Option<CubeMapFace>

Face of the cube map, this field is used only if the texture is a cube map. This indicates which face of the cube will be rendered to.

pub fn set_level(&self, level: usize)

Mip level of the texture where the rendering should happen. In most cases, it can be zero.

pub fn set_cube_map_face(&self, face: Option<CubeMapFace>)

Face of the cube map, this field is used only if the texture is a cube map. This indicates which face of the cube will be rendered to.

pub fn color(texture: GpuTexture) -> Self

Creates a new AttachmentKind::Color attachment with the given texture.

pub fn color_with_level(texture: GpuTexture, level: usize) -> Self

Creates a new AttachmentKind::Color attachment with the given texture and the mip level.

pub fn color_with_face(texture: GpuTexture, cube_map_face: CubeMapFace) -> Self

Creates a new AttachmentKind::Color attachment with the given texture and the cube map face. The texture must be a cube map.

pub fn depth(texture: GpuTexture) -> Self

Creates a new AttachmentKind::Depth attachment with the given texture.

pub fn depth_stencil(texture: GpuTexture) -> Self

Creates a new AttachmentKind::DepthStencil attachment with the given texture.