pub enum ElementsDescriptor<'a> {
Triangles(&'a [TriangleDefinition]),
Lines(&'a [[u32; 2]]),
Points(&'a [u32]),
}Expand description
Describes elements for the geometry buffer.
Variants
Triangles(&'a [TriangleDefinition])
Triangles are formed by a triple of vertex indices.
Lines(&'a [[u32; 2]])
Lines are formed by a pair of vertex indices.
Points(&'a [u32])
Points are just straight vertex indices.
Implementations
Sourceimpl ElementsDescriptor<'_>
impl ElementsDescriptor<'_>
Sourcepub fn element_kind(&self) -> ElementKind
pub fn element_kind(&self) -> ElementKind
Returns element kind of the elements’ descriptor.