pub struct AttributeDefinition {
pub location: u32,
pub kind: AttributeKind,
pub component_count: usize,
pub normalized: bool,
pub divisor: u32,
}Expand description
Vertex attribute definition.
Fields
location: u32Binding point of the vertex attribute.
kind: AttributeKindVertex attribute kind. See AttributeKind docs for more info.
component_count: usizeComponent count in the vertex. This could be 1,2,3 or 4.
normalized: boolA flag, that defines whether the attribute is normalized or not. Normalized attributes
are always real numbers in [-1.0; 1.0] range (or [0.0; 1.0] for unsigned attributes).
divisor: u32Defines feed rate of the vertex attribute. 0 - means that the attribute will be unique per vertex, 1 - per each drawn instance, 2 - per two instances and so on.