pub struct VertexBufferDescriptor<'a> {
pub usage: BufferUsage,
pub attributes: &'a [AttributeDefinition],
pub data: VertexBufferData<'a>,
}Expand description
Vertex buffer descriptor contains information about vertex buffer layout and content usage as well as the data that will be uploaded to GPU.
Fields
usage: BufferUsageVertex buffer usage. See BufferUsage docs for more info.
attributes: &'a [AttributeDefinition]Attributes of the vertex buffer.
data: VertexBufferData<'a>Data of the vertex buffer. See VertexBufferData docs for more info.