SamplerKind

Enum SamplerKind 

pub enum SamplerKind {
    Sampler1D,
    Sampler2D,
    Sampler3D,
    SamplerCube,
    USampler1D,
    USampler2D,
    USampler3D,
    USamplerCube,
}
A sampler represents how the data of a texture is accessed, and different kinds of samplers are intended for different kinds of textures.

Variants



Sampler1D

A sampler for a 1D linear texture, a series of values that are indexed by a single coordinate and where each component of the value is a float.



Sampler2D

A sampler for the usual 2D image texture, a flat area of values that are indexed by a pair of coordinates (x, y) and where each component of the value is a float.



Sampler3D

A sampler for a 3D texture, a volume of values that are indexed by three coordinates (x, y, z) and where each component of the value is a float.



SamplerCube

A sampler for six square 2D images where each image represents one face of a cube. It is indexed by a three coordinate direction from the center of the cube (x, y, z) where the magnitude of the coordinates do not matter. The sampler follows the direction of the coordinates until it finds a place on one of the six faces of the cube. Each component of the resulting value is a float.



USampler1D

A sampler for a 1D linear texture, a series of values that are indexed by a single coordinate and where each component of the value is an unsigned integer.



USampler2D

A sampler for the usual 2D image texture, a flat area of values that are indexed by a pair of coordinates (x, y) and where each component of the value is an unsigned integer.



USampler3D

A sampler for a 3D texture, a volume of values that are indexed by three coordinates (x, y, z) and where each component of the value is an unsigned integer.



USamplerCube

A sampler for six square 2D images where each image represents one face of a cube. It is indexed by a three coordinate direction from the center of the cube (x, y, z) where the magnitude of the coordinates do not matter. The sampler follows the direction of the coordinates until it finds a place on one of the six faces of the cube. Each component of the resulting value is an unsigned integer.