ShaderKind

Enum ShaderKind 

pub enum ShaderKind {
    Vertex,
    Fragment,
}
A shader can be either a fragment shader that produces pixels or a vertex shader that controls where triangles are drawn on the screen.

Variants



Vertex

A vertex shader takes vertices in world coordinates and mathematically transforms them into screen coordinates for rendering. The vertex shader runs before the fragment shader and creates the input to the fragment shader.



Fragment

The fragment shader determines whether a pixel should be drawn and what color it should be. It uses the data produced by the vertex shader after it has been interpolated by the GPU for the particular pixel under consideration.