GpuTextureDescriptor

Struct GpuTextureDescriptor 

pub struct GpuTextureDescriptor<'a> {
    pub name: &'a str,
    pub kind: GpuTextureKind,
    pub pixel_kind: PixelKind,
    pub mip_count: usize,
    pub data: Option<&'a [u8]>,
    pub base_level: usize,
    pub max_level: usize,
}
Descriptor of a texture that is used to request textures from a graphics server.

Fields

name: &'a str

Name of the texture. This name is used only for debug purposes.

kind: GpuTextureKind

Kind of the texture. See GpuTextureKind docs for more info.

pixel_kind: PixelKind

Pixel kind of the texture. See PixelKind docs for more info.

mip_count: usize

Total number of mips in the texture. Texture data must contain at least this number of mips.

data: Option<&'a [u8]>

Optional data of the texture. If present, then the total number of bytes must match the required number of bytes defined by the texture kind, pixel kind, mip count.

base_level: usize

Specifies the index of the lowest defined mipmap level. Keep in mind, that the texture data should provide the actual mip map level defined by the provided value, otherwise the rendering will be incorrect (probably just black on majority of implementations) and glitchy.

max_level: usize

Sets the index of the highest defined mipmap level. Keep in mind, that the texture data should provide the actual mip map level defined by the provided value, otherwise the rendering will be incorrect (probably just black on majority of implementations) and glitchy.