WrapMode

Enum WrapMode 

pub enum WrapMode {
    Repeat,
    ClampToEdge,
    ClampToBorder,
    MirroredRepeat,
    MirrorClampToEdge,
}
Defines a law of texture coordinate modification.

Variants



Repeat

Causes the integer part of a coordinate to be ignored; GPU uses only the fractional part, thereby creating a repeating pattern.



ClampToEdge

Causes a coordinates to be clamped to the range, where N is the size of the texture in the direction of clamping



ClampToBorder

Evaluates a coordinates in a similar manner to ClampToEdge. However, in cases where clamping would have occurred in ClampToEdge mode, the fetched texel data is substituted with the values specified by border color.



MirroredRepeat

Causes the coordinate to be set to the fractional part of the texture coordinate if the integer part of coordinate is even; if the integer part of coordinate is odd, then the coordinate texture coordinate is set to 1-frac, where frac represents the fractional part of coordinate.



MirrorClampToEdge

Causes a coordinate to be repeated as for MirroredRepeat for one repetition of the texture, at which point the coordinate to be clamped as in ClampToEdge.