GpuSamplerDescriptor

Struct GpuSamplerDescriptor 

pub struct GpuSamplerDescriptor {
    pub min_filter: MinificationFilter,
    pub mag_filter: MagnificationFilter,
    pub s_wrap_mode: WrapMode,
    pub t_wrap_mode: WrapMode,
    pub r_wrap_mode: WrapMode,
    pub anisotropy: f32,
    pub min_lod: f32,
    pub max_lod: f32,
    pub lod_bias: f32,
}
A set of potential options that can be used to configure a GPU sampler.

Fields

min_filter: MinificationFilter

Minification filter of the texture. See MinificationFilter docs for more info.

mag_filter: MagnificationFilter

Magnification filter of the texture. See MagnificationFilter docs for more info.

s_wrap_mode: WrapMode

S coordinate wrap mode. See WrapMode docs for more info.

t_wrap_mode: WrapMode

T coordinate wrap mode. See WrapMode docs for more info.

r_wrap_mode: WrapMode

R coordinate wrap mode. See WrapMode docs for more info.

anisotropy: f32

Anisotropy level of the texture. Default is 1.0. Max number is usually depends on the GPU, but the cap is 16.0 on pretty much any platform. This number should be a power of two.

min_lod: f32

Sets the minimum level-of-detail parameter. This floating-point value limits the selection of highest resolution mipmap (lowest mipmap level). The initial value is -1000.0.

max_lod: f32

Sets the maximum level-of-detail parameter. This floating-point value limits the selection of the lowest resolution mipmap (highest mipmap level). The initial value is 1000.0.

lod_bias: f32

Specifies a fixed bias value that is to be added to the level-of-detail parameter for the texture before texture sampling. The specified value is added to the shader-supplied bias value (if any) and subsequently clamped into the implementation-defined range −bias_max..bias_max, where bias_max is the value that can be fetched from the current graphics server. The initial value is 0.0.

Implementations

Source

impl GpuSamplerDescriptor

pub fn new_rt_sampler() -> Self

Create a sampler for a rander target.