pub struct ServerCapabilities {
pub max_uniform_block_size: usize,
pub uniform_buffer_offset_alignment: usize,
pub max_lod_bias: f32,
}Expand description
Graphics server capabilities.
Fields
max_uniform_block_size: usizeThe maximum size in basic machine units of a uniform block, which must be at least 16384.
uniform_buffer_offset_alignment: usizeThe minimum required alignment for uniform buffer sizes and offset. The initial value is 1.
max_lod_bias: f32The maximum, absolute value of the texture level-of-detail bias. The value must be at least 2.0.