pub struct ServerMemoryUsage {
pub textures: usize,
pub buffers: usize,
}Expand description
Contains information about used memory per each category of GPU resource. This is not precise data; it only calculates total requested memory by the user of a graphics server and does not include additional memory overhead in the video driver. Yet this information could still be useful.
Fields
textures: usizeTotal number of bytes used by all textures (including render targets).
buffers: usizeTotal number of bytes used by all buffers (vertex, index, uniform, etc.)