pub struct GpuBufferDescriptor<'a> {
pub name: &'a str,
pub size: usize,
pub kind: BufferKind,
pub usage: BufferUsage,
}Expand description
Specifications for a buffer that are passed to crate::server::GraphicsServer::create_buffer so that the server
knows what buffer to create.
Fields
name: &'a strA label for the buffer for debugging, as might be passed to glObjectLabel in an OpenGL server.
size: usizeThe size of the buffer in bytes, as might be passed to glBufferData in an OpenGL server.
kind: BufferKindWhat is stored in the buffer? Vertices, indices, uniforms, pixels, etc.
usage: BufferUsageAn efficiency hint for how the buffer will be used.