pub enum ResourceBinding {
Texture {
texture: GpuTexture,
sampler: GpuSampler,
binding: usize,
},
Buffer {
buffer: GpuBuffer,
binding: usize,
data_usage: BufferDataUsage,
},
}Expand description
A resource binding defines where to bind specific GPU resources.
Variants
Texture
Texture binding.
Fields

texture: GpuTextureA shared reference to a texture.

sampler: GpuSamplerA sampler that will be used to fetch the data from the texture.
Buffer
Generic data buffer binding.
Fields

buffer: GpuBufferA shared reference to a buffer.

data_usage: BufferDataUsageData portion to use.
Implementations