pub struct GpuTextureDescriptor<'a> {
pub name: &'a str,
pub kind: GpuTextureKind,
pub pixel_kind: PixelKind,
pub mip_count: usize,
pub data: Option<&'a [u8]>,
pub base_level: usize,
pub max_level: usize,
}Expand description
Descriptor of a texture that is used to request textures from a graphics server.
Fields
name: &'a strName of the texture. This name is used only for debug purposes.
kind: GpuTextureKindKind of the texture. See GpuTextureKind docs for more info.
pixel_kind: PixelKindPixel kind of the texture. See PixelKind docs for more info.
mip_count: usizeTotal number of mips in the texture. Texture data must contain at least this number of mips.
data: Option<&'a [u8]>Optional data of the texture. If present, then the total number of bytes must match the required number of bytes defined by the texture kind, pixel kind, mip count.
base_level: usizeSpecifies the index of the lowest defined mipmap level. Keep in mind, that the texture data should provide the actual mip map level defined by the provided value, otherwise the rendering will be incorrect (probably just black on majority of implementations) and glitchy.
max_level: usizeSets the index of the highest defined mipmap level. Keep in mind, that the texture data should provide the actual mip map level defined by the provided value, otherwise the rendering will be incorrect (probably just black on majority of implementations) and glitchy.